==> StanHeaders_2.11.0.tar.gz: StanHeaders/inst/include/src/stan/mcmc/hmc/static/adapt_diag_e_static_hmc.hpp <==
#ifndef STAN_MCMC_HMC_STATIC_ADAPT_DIAG_E_STATIC_HMC_HPP
#define STAN_MCMC_HMC_STATIC_ADAPT_DIAG_E_STATIC_HMC_HPP

#include <stan/interface_callbacks/writer/base_writer.hpp>
#include <stan/mcmc/hmc/static/diag_e_static_hmc.hpp>
#include <stan/mcmc/stepsize_var_adapter.hpp>

namespace stan {
  namespace mcmc {
    /**
     * Hamiltonian Monte Carlo implementation using the endpoint
     * of trajectories with a static integration time with a
     * Gaussian-Euclidean disintegration and adaptive diagonal metric and
     * adaptive step size
     */
    template <class Model, class BaseRNG>
    class adapt_diag_e_static_hmc : public diag_e_static_hmc<Model, BaseRNG>,
                                    public stepsize_var_adapter {
    public:
      adapt_diag_e_static_hmc(const Model& model, BaseRNG& rng)
        : diag_e_static_hmc<Model, BaseRNG>(model, rng),
        stepsize_var_adapter(model.num_params_r()) {}

      ~adapt_diag_e_static_hmc() {}

      sample
      transition(sample& init_sample,
                 interface_callbacks::writer::base_writer& info_writer,
                 interface_callbacks::writer::base_writer& error_writer) {
        sample s
          = diag_e_static_hmc<Model, BaseRNG>::transition(init_sample,
                                                          info_writer,
                                                          error_writer);

        if (this->adapt_flag_) {
          this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
                                                    s.accept_stat());
          this->update_L_();

          bool update = this->var_adaptation_.learn_variance(this->z_.mInv,
                                                             this->z_.q);

          if (update) {
            this->init_stepsize(info_writer, error_writer);
            this->update_L_();

            this->stepsize_adaptation_.set_mu(log(10 * this->nom_epsilon_));
            this->stepsize_adaptation_.restart();
          }
        }
        return s;
      }

      void disengage_adaptation() {
        base_adapter::disengage_adaptation();
        this->stepsize_adaptation_.complete_adaptation(this->nom_epsilon_);
      }
    };

  }  // mcmc
}  // stan
#endif

==> StanHeaders_2.15.0-1.tar.gz: StanHeaders/inst/include/src/stan/mcmc/hmc/static/adapt_diag_e_static_hmc.hpp <==
#ifndef STAN_MCMC_HMC_STATIC_ADAPT_DIAG_E_STATIC_HMC_HPP
#define STAN_MCMC_HMC_STATIC_ADAPT_DIAG_E_STATIC_HMC_HPP

#include <stan/callbacks/writer.hpp>
#include <stan/mcmc/hmc/static/diag_e_static_hmc.hpp>
#include <stan/mcmc/stepsize_var_adapter.hpp>

namespace stan {
  namespace mcmc {
    /**
     * Hamiltonian Monte Carlo implementation using the endpoint
     * of trajectories with a static integration time with a
     * Gaussian-Euclidean disintegration and adaptive diagonal metric and
     * adaptive step size
     */
    template <class Model, class BaseRNG>
    class adapt_diag_e_static_hmc : public diag_e_static_hmc<Model, BaseRNG>,
                                    public stepsize_var_adapter {
    public:
      adapt_diag_e_static_hmc(const Model& model, BaseRNG& rng)
        : diag_e_static_hmc<Model, BaseRNG>(model, rng),
        stepsize_var_adapter(model.num_params_r()) {}

      ~adapt_diag_e_static_hmc() {}

      sample
      transition(sample& init_sample,
                 callbacks::writer& info_writer,
                 callbacks::writer& error_writer) {
        sample s
          = diag_e_static_hmc<Model, BaseRNG>::transition(init_sample,
                                                          info_writer,
                                                          error_writer);

        if (this->adapt_flag_) {
          this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
                                                    s.accept_stat());
          this->update_L_();

          bool update = this->var_adaptation_.learn_variance(this->z_.mInv,
                                                             this->z_.q);

          if (update) {
            this->init_stepsize(info_writer, error_writer);
            this->update_L_();

            this->stepsize_adaptation_.set_mu(log(10 * this->nom_epsilon_));
            this->stepsize_adaptation_.restart();
          }
        }
        return s;
      }

      void disengage_adaptation() {
        base_adapter::disengage_adaptation();
        this->stepsize_adaptation_.complete_adaptation(this->nom_epsilon_);
      }
    };

  }  // mcmc
}  // stan
#endif
